==> neo4j-bolt-5.12.0-sources.jar: org/neo4j/bolt/protocol/common/connection/DefaultConnectionHintProvider.java <==
/*
 * Copyright (c) "Neo4j"
 * Neo4j Sweden AB [https://neo4j.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
package org.neo4j.bolt.protocol.common.connection;

import java.util.function.Function;
import org.neo4j.configuration.Config;
import org.neo4j.configuration.connectors.BoltConnector;
import org.neo4j.values.storable.Values;

public final class DefaultConnectionHintProvider {
    private static final String HINT_CONNECTION_RECV_TIMEOUT_SECONDS = "connection.recv_timeout_seconds";

    public static final Function<Config, ConnectionHintProvider> CONNECTION_HINT_PROVIDER_FUNCTION =
            config -> hints -> {
                if (config.get(BoltConnector.connection_keep_alive_type) == BoltConnector.KeepAliveRequestType.ALL) {
                    var keepAliveInterval = config.get(BoltConnector.connection_keep_alive);
                    var keepAliveProbes = config.get(BoltConnector.connection_keep_alive_probes);

                    hints.add(
                            HINT_CONNECTION_RECV_TIMEOUT_SECONDS,
                            Values.longValue(keepAliveInterval.toSeconds() * keepAliveProbes));
                }
            };

    private DefaultConnectionHintProvider() {}
}

==> neo4j-bolt-5.13.0-sources.jar: org/neo4j/bolt/protocol/common/connection/DefaultConnectionHintProvider.java <==
/*
 * Copyright (c) "Neo4j"
 * Neo4j Sweden AB [https://neo4j.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
package org.neo4j.bolt.protocol.common.connection;

import java.util.function.Function;
import org.neo4j.configuration.Config;
import org.neo4j.configuration.connectors.BoltConnector;
import org.neo4j.values.storable.Values;

public final class DefaultConnectionHintProvider {
    private static final String HINT_CONNECTION_RECV_TIMEOUT_SECONDS = "connection.recv_timeout_seconds";
    private static final String HINT_DRIVER_TELEMETRY_ENABLED = "telemetry.enabled";

    public static final Function<Config, ConnectionHintProvider> CONNECTION_HINT_PROVIDER_FUNCTION =
            config -> hints -> {
                if (config.get(BoltConnector.connection_keep_alive_type) == BoltConnector.KeepAliveRequestType.ALL) {
                    var keepAliveInterval = config.get(BoltConnector.connection_keep_alive);
                    var keepAliveProbes = config.get(BoltConnector.connection_keep_alive_probes);

                    hints.add(
                            HINT_CONNECTION_RECV_TIMEOUT_SECONDS,
                            Values.longValue(keepAliveInterval.toSeconds() * keepAliveProbes));
                }

                hints.add(
                        HINT_DRIVER_TELEMETRY_ENABLED,
                        Values.booleanValue(config.get(BoltConnector.server_bolt_telemetry_enabled)));
            };

    private DefaultConnectionHintProvider() {}
}
